@@ -67,6 +67,7 @@ class SQLiteURLTable(BaseURLTable):
         self._connection = sqlite3.connect(path)
         self._apply_pragmas()
         self._create_tables()
+        self._create_indexes()
         self._connection.row_factory = URLRecord
 
     def _apply_pragmas(self):
@@ -91,6 +92,11 @@ class SQLiteURLTable(BaseURLTable):
             '''
         )
 
+    def _create_indexes(self):
+        self._connection.execute(
+            '''CREATE INDEX IF NOT EXISTS url_status_index ON urls (status)'''
+        )
+
     def __getitem__(self, url):
         query = '''SELECT * FROM urls WHERE url = ?'''
         cursor = self._connection.execute(query, (url,))
